@@ -1,10 +1,13 @@
 import traceback
 from counter import Counter
-from controller import ParentDeadException
+from controller import Controller, ParentDeadException
+from helper import Helper
 
 class Each:
+  def __init__(self, app):
+    self._app = app
 
-  def __init__(self, name, emits, output_format, prepare, execute, parallelism):
+  def build_node(self, name, emits, output_format, prepare, execute, parallelism):
     self._name = name if name else "each_"+Counter.get()
     self._type = "each"
     self._output_format = output_format
@@ -19,7 +22,14 @@ class Each:
     self._execute = execute
     self._parallelism = parallelism
 
-  def run(self, controller):
+    Helper.check_name("each", self._name, self._app._names)
+    Helper.check_each(self)
+    Helper.check_emits("each", self._emits, self._app._streams)
+
+  def run_operation(self):
+    pipe_name = self._app._options.get("pipe","")
+    controller = Controller(pipe_name, self._emits)
+
     controller.get_pidDir()
     if self._prepare != None:
       self._prepare(controller)
