@@ -1,9 +1,13 @@
 import traceback
 from counter import Counter
-from controller import ParentDeadException
+from controller import Controller, ParentDeadException
+from helper import Helper
 
 class Filter:
-  def __init__(self, name, emits, prepare, keep, parallelism):
+  def __init__(self, app):
+    self._app = app
+
+  def build_node(self, name, emits, prepare, keep, parallelism):
     self._name = name if name else "filter_"+Counter.get()
     self._type = "filter"
 
@@ -17,8 +21,14 @@ class Filter:
     self._keep = keep
     self._parallelism = parallelism
 
+    Helper.check_name("filter", self._name, self._app._names)
+    Helper.check_filter(self)
+    Helper.check_emits("filter", self._emits, self._app._streams)
+
+  def run_operation(self):
+    pipe_name = self._app._options.get("pipe","")
+    controller = Controller(pipe_name, self._emits)
 
-  def run(self, controller):
     controller.get_pidDir()
     if self._prepare != None:
       self._prepare(controller)
