@@ -1,9 +1,13 @@
 import traceback
 from counter import Counter
-from controller import ParentDeadException
+from controller import Controller, ParentDeadException
+from helper import Helper
 
 class GroupBy:
-  def __init__(self, name, emits, fields, begin_group, aggregate, end_group, parallelism):
+  def __init__(self, app):
+    self._app = app
+  
+  def build_node(self, name, emits, fields, begin_group, aggregate, end_group, parallelism):
     self._name = name if name else "group_by_"+Counter.get()
     self._type = "group_by"
 
@@ -19,7 +23,14 @@ class GroupBy:
     self._end_group = end_group
     self._parallelism = parallelism
 
-  def run(self, controller):
+    Helper.check_name("group_by", self._name, self._app._names)
+    Helper.check_group_by(self)
+    Helper.check_emits("group_by", self._emits, self._app._streams)
+
+  def run_operation(self):
+    pipe_name = self._app._options.get("pipe","")
+    controller = Controller(pipe_name, self._emits)
+
     controller.get_pidDir()
 
     while True:
