@@ -227,19 +227,22 @@ class Helper:
     self.check_output_format("call_component", node._output_format)
 
   @classmethod
-  def check_sink(self, name, columns, nodes):
-    ee = "Error in \"sink\": \n\t "
-    pp = self.print_check_sink
+  def check_sink(self, name, columns, nodes, operation):
+    ee = "Error in \"%s\": \n\t "%(operation)
+    if operation == "sink":
+      pp = self.print_check_sink
+    elif operation == "outputs":
+      pp = self.print_check_component_sink
   
     if not name:
       msg = ee+"Relation name must be specified!"+pp
       self.print_error(msg)
-    self.check_name("sink", name, {})
+    self.check_name(operation, name, {})
   
     if len(columns) == 0:
       msg = ee+"Must be at least one output field to relation \"%s\"."%(name)+pp
       self.print_error(msg)
-    self.check_field_format("sink", pp, name, columns)
+    self.check_field_format(operation, pp, name, columns)
   
     for node in nodes:
       if node._type != "sink":
@@ -367,6 +370,16 @@ class Helper:
   - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
   - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
   - Field types may be "string", "integer", "float", "double", or "boolean"."""
+  
+  print_check_component_sink = """\n
+"Outputs" Syntax:
+  stream.outputs( name = "output_stream_name",
+                  columns = [{"field_1" : "type_1"}, {"field_2" : "type_2"}, ...] )
+  - "Outputs" stream "name" must be specified as a non-empty STRING with only alphanumeric and underscore characters!
+  - "Columns" must be a non-empty LIST.
+  - Field names must be non-empty STRINGS with only alphanumeric or underscore characters.
+  - Field names cannot be "v[number]", "id", "confidence", "since" or "source" which are reserved Zillabyte names.
+  - Field types may be "string", "integer", "float", "double", or "boolean"."""
 
   print_check_component_source = """\n
 "Inputs" Syntax:
