@@ -1,9 +1,15 @@
 from counter import Counter
+from helper import Helper
 
 class Join:
-  def __init__(self, name, emits, fields, options):
+  def __init__(self, app):
+    self._app = app
+
+  def build_node(self, name, lhs_stream, rhs_stream, emits, fields, options):
     self._name = name if name else "join_"+Counter.get()
     self._type = "join"
+    self._lhs_stream = lhs_stream
+    self._rhs_stream = rhs_stream
 
     if emits == None:
       emits = ["stream_"+Counter.get()]
@@ -23,3 +29,10 @@ class Join:
     if options:
       if options["type"]:
         self._join_type = options["type"]
+
+    Helper.check_name("join", self._name, self._app._names)
+    Helper.check_join(self)
+    Helper.check_emits("join", self._emits, self._app._streams)
+
+  def run_operation(self):
+    print "Joins can only be instantiated on our cluster, sorry!"
