@@ -1,16 +1,22 @@
 import traceback
 from counter import Counter
-from controller import ParentDeadException, UserEndCycleException
+from controller import Controller, ParentDeadException, UserEndCycleException
+from helper import Helper
 
 class Source:
-  def __init__(self, name, matches, options, emits, end_cycle_policy, begin_cycle, next_tuple):
+  def __init__(self, app):
+    self._app = app
+
+  def build_node(self, name, matches, options, emits, end_cycle_policy, begin_cycle, next_tuple):
     self._name = name if name else "source_"+Counter.get()
     self._type = "source"
+    self._options = options
     self._matches = None
     self._relation = None
     self._end_cycle_policy = None
 
     if(matches != None):
+      Helper.check_matches(matches)
       if isinstance(matches, basestring):
         if not isinstance(options, dict):
           options = {}
@@ -29,7 +35,14 @@ class Source:
     self._begin_cycle = begin_cycle
     self._next_tuple = next_tuple
 
-  def run(self, controller):
+    Helper.check_name("source", self._name, self._app._names)
+    Helper.check_source(self)
+    Helper.check_emits("source", self._emits, self._app._streams)
+
+  def run_operation(self):
+    pipe_name = self._app._options.get("pipe","")
+    controller = Controller(pipe_name, self._emits)
+
     controller.get_pidDir()
 
     while True:
